@@ -3,59 +3,59 @@
     window.SGGoogleAnalytics = ( function()
     {
         var app = {},
-          settings = {
-              trackingVersion: 1,
-              trackVersion: true,
-              trackClientId: true,
-              trackWindowId: true,
-              trackIndividualHits: true,
-              trackErrors: true,
-              trackPerformance: true,
-              trackDownloads: true,
-              trackOutboundLinks: true,
-              trackSGEstateSearchBoxSend: false,
-              // map the ga dimension indizes to our internal tracking dimensions
-              dimensionTrackingVersion: 'dimension1',
-              dimensionClientId: 'dimension2',
-              dimensionWindowId: 'dimension3',
-              dimensionHitId: 'dimension4',
-              dimensionHitTime: 'dimension5',
-              dimensionHitType: 'dimension6',
-              // map the ga metric indizes to our internal metric identifiers
-              metricServerResponseEnd: 'metric1',
-              metricDOMContentLoaded: 'metric2',
-              metricPageLoaded: 'metric3',
-              metricSGEstateSearchBoxSize: 'metric4',
-              metricSGEstateSearchBoxRooms: 'metric5',
-              metricSGEstateSearchBoxRent: 'metric6',
-              sgEstateSearchBoxSizeSelector: '#flatSizeMinField',
-              sgEstateSearchBoxRoomsSelector: '#flatRoomsMinField',
-              sgEstateSearchBoxRentSelector: '#flatAmountMaxField',
-              sgEstateSearchBoxEventTriggerSelector: '#flatSearchForm',
-              // map event names
-              eventDownloadsCategory: 'download',
-              eventDownloadsFileTypes: ['pdf'],
-              eventOutboundCategory: 'outbound',
-              eventOutboundAction: 'click',
-              // GA tracking property
-              property: false,
-              disableLinkSelector: '.sggoogleanalytics-optout',
-              disableLinkIdle: false,
-              disableCookieIdentifier: 'ga-disable-',
-              textDisableSuccess: 'Optout für diese Seite erfolgreich gesetzt. Google Analytics erfasst in diesem Browser keine Statistiken mehr zu dieser Webseite.',
-              debug: false,
-          },
-          clientId = false,
-          windowId = false,
-          hitId = false,
-          hitTime = false,
-          disabled = false,
-          pagePerformance = {
-              serverResponseEnd: false,
-              domContentLoaded: false,
-              pageLoaded: false
-          },
-          $sgEstateSearchBoxTrigger = false;
+            settings = {
+                trackingVersion: 1,
+                trackVersion: true,
+                trackClientId: false,
+                trackWindowId: false,
+                trackIndividualHits: true,
+                trackErrors: true,
+                trackPerformance: true,
+                trackDownloads: false,
+                trackOutboundLinks: false,
+                trackSGEstateSearchBoxSend: false,
+                // map the ga dimension indizes to our internal tracking dimensions
+                dimensionTrackingVersion: 'dimension1',
+                dimensionClientId: 'dimension2',
+                dimensionWindowId: 'dimension3',
+                dimensionHitId: 'dimension4',
+                dimensionHitTime: 'dimension5',
+                dimensionHitType: 'dimension6',
+                // map the ga metric indizes to our internal metric identifiers
+                metricServerResponseEnd: 'metric1',
+                metricDOMContentLoaded: 'metric2',
+                metricPageLoaded: 'metric3',
+                metricSGEstateSearchBoxSize: 'metric4',
+                metricSGEstateSearchBoxRooms: 'metric5',
+                metricSGEstateSearchBoxRent: 'metric6',
+                sgEstateSearchBoxSizeSelector: '#flatSizeMinField',
+                sgEstateSearchBoxRoomsSelector: '#flatRoomsMinField',
+                sgEstateSearchBoxRentSelector: '#flatAmountMaxField',
+                sgEstateSearchBoxEventTriggerSelector: '#flatSearchForm',
+                // map event names
+                eventDownloadsCategory: 'download',
+                eventDownloadsFileTypes: ['pdf'],
+                eventOutboundCategory: 'outbound',
+                eventOutboundAction: 'click',
+                // GA tracking property
+                property: false,
+                disableLinkSelector: '.sggoogleanalytics-optout',
+                disableLinkIdle: false,
+                disableCookieIdentifier: 'ga-disable-',
+                textDisableSuccess: 'Optout für diese Seite erfolgreich gesetzt. Google Analytics erfasst in diesem Browser keine Statistiken mehr zu dieser Webseite.',
+                debug: false,
+            },
+            clientId = false,
+            windowId = false,
+            hitId = false,
+            hitTime = false,
+            disabled = false,
+            pagePerformance = {
+                serverResponseEnd: false,
+                domContentLoaded: false,
+                pageLoaded: false
+            },
+            $sgEstateSearchBoxTrigger = false;
 
         /**
          * Add a version of a set of tracking dimensions and metrics state to the data set
@@ -133,7 +133,7 @@
         var generateUniqueWindowID = function b(a)
         {
             return a ? (a ^ Math.random() * 16 >> a / 4).toString(16) :
-              ([1e7] + -1e3 + -4e3 + -8e3 + -1e11).replace(/[018]/g, b);
+                ([1e7] + -1e3 + -4e3 + -8e3 + -1e11).replace(/[018]/g, b);
         };
 
         /**
@@ -244,8 +244,8 @@
 
                 // check if all metric values are somehow valid
                 if( isIntegerValueValid( pagePerformance.serverResponseEnd ) &&
-                  isIntegerValueValid( pagePerformance.domContentLoaded ) &&
-                  isIntegerValueValid( pagePerformance.pageLoaded ) )
+                    isIntegerValueValid( pagePerformance.domContentLoaded ) &&
+                    isIntegerValueValid( pagePerformance.pageLoaded ) )
                 {
                     // now send event
                     var fieldObj = {
@@ -292,20 +292,22 @@
                         trackDownloadsSelector = trackDownloadsSelector + 'a[href$=".'+settings.eventDownloadsFileTypes[i]+'"]';
                     }
                 }
-                $( trackDownloadsSelector ).on('click', function( e )
-                {
-                    e.preventDefault();
-                    // better use this.href because we always receive the absolute path w/ domain
-                    var url = this.href;
-                    // clean up url, remove domain
-                    var urlNoDomain = url.replace(/https?:\/\/[^\/]+/i, "");
-                    var extension = url.substr( (url.lastIndexOf('.') +1) );
-                    // send event
-                    ga('send', 'event', settings.eventDownloadsCategory, extension, urlNoDomain, {
-                        'transport': 'beacon',
-                        'hitCallback': function(){document.location = url;}
+                if( trackDownloadsSelector !== '' ) {
+                    $( trackDownloadsSelector ).on('click', function( e )
+                    {
+                        e.preventDefault();
+                        // better use this.href because we always receive the absolute path w/ domain
+                        var url = this.href;
+                        // clean up url, remove domain
+                        var urlNoDomain = url.replace(/https?:\/\/[^\/]+/i, "");
+                        var extension = url.substr( (url.lastIndexOf('.') +1) );
+                        // send event
+                        ga('send', 'event', settings.eventDownloadsCategory, extension, urlNoDomain, {
+                            'transport': 'beacon',
+                            'hitCallback': function(){document.location = url;}
+                        });
                     });
-                });
+                }
             }
         };
 
@@ -583,37 +585,40 @@
                 {
                     console.log("SGGoogleAnalytics.init: disabled: %s", disabled );
                 }
-                // initialize GA asynchronously
-                // may lead to synchronous loading in older browsers ( < IE10 etc.)
-                // but uses full potential of preloading and caching of assets
-                window.ga = window.ga || function(){(ga.q=ga.q||[]).push(arguments)};ga.l=+new Date;
+                //only proceed if not disabled
+                if( !disabled ) {
+                    // initialize GA asynchronously
+                    // may lead to synchronous loading in older browsers ( < IE10 etc.)
+                    // but uses full potential of preloading and caching of assets
+                    window.ga = window.ga || function(){(ga.q=ga.q||[]).push(arguments)};ga.l=+new Date;
 
-                // init google analytics global ga queue
-                ga('create', settings.property, 'auto');
-                if( settings.debug )
-                {
-                    console.log("SGGoogleAnalytics.init: property: %s", settings.property );
+                    // init google analytics global ga queue
+                    ga('create', settings.property, 'auto');
+                    if( settings.debug )
+                    {
+                        console.log("SGGoogleAnalytics.init: property: %s", settings.property );
+                    }
+                    ga('set', 'anonymizeIp', true);
+                    // set transport method to beacon to ensure proper sending of data
+                    // even if the tracking page was left
+                    ga('set', 'transport', 'beacon');
+                    // add custom dimensions, metrics and events according to settings
+                    trackVersion();
+                    trackClientId();
+                    trackWindowId();
+                    trackIndividualHits();
+                    trackErrors();
+                    trackPerformance();
+                    trackDownloads();
+                    trackOutboundLinks();
+                    trackSGEstateSearchBoxSend();
+
+                    // register optout link events
+                    registerOptoutEvent();
+
+                    // last thing, send pageview
+                    ga('send', 'pageview');
                 }
-                ga('set', 'anonymizeIp', true);
-                // set transport method to beacon to ensure proper sending of data
-                // even if the tracking page was left
-                ga('set', 'transport', 'beacon');
-                // add custom dimensions, metrics and events according to settings
-                trackVersion();
-                trackClientId();
-                trackWindowId();
-                trackIndividualHits();
-                trackErrors();
-                trackPerformance();
-                trackDownloads();
-                trackOutboundLinks();
-                trackSGEstateSearchBoxSend();
-
-                // register optout link events
-                registerOptoutEvent();
-
-                // last thing, send pageview
-                ga('send', 'pageview');
             }
         };
 
